summaryrefslogtreecommitdiff
path: root/django
diff options
context:
space:
mode:
Diffstat (limited to 'django')
-rw-r--r--django/db/migrations/autodetector.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/django/db/migrations/autodetector.py b/django/db/migrations/autodetector.py
index c3a3424cd1..6f7f446c84 100644
--- a/django/db/migrations/autodetector.py
+++ b/django/db/migrations/autodetector.py
@@ -254,13 +254,13 @@ class MigrationAutodetector(object):
# If we can't find the other app, we add a first/last dependency,
# but only if we've already been through once and checked everything
if chop_mode:
# If the app already exists, we add __last__, as we don't know which
# migration contains the target field.
# If it's not yet migrated or has no migrations, we use __first__
if graph and not graph.root_nodes(dep[0]):
operation_dependencies.add((dep[0], "__first__"))
else:
- operation_dependencies.add((dep[0], "__last__"))
+ operation_dependencies.add((dep[0], "__latest__"))
else:
deps_satisfied = False
if deps_satisfied:
@@ -254,13 +254,13 @@ class MigrationAutodetector(object):
# but only if we've already been through once and checked everything
if chop_mode:
- # If the app already exists, we add __last__, as we don't know which
+ # If the app already exists, we add __latest__, as we don't know which
# migration contains the target field.
# If it's not yet migrated or has no migrations, we use __first__